gensim: models.lsi_worker – Worker for distributed LSI
Description: Efficient topic modelling of text semantics in Python.

#

### Get Expert Help

• machine learning, NLP, data mining

• custom SW design, development, optimizations

• tech trainings & IT consulting

models.lsi_worker – Worker for distributed LSI

# `models.lsi_worker` – Worker for distributed LSI

USAGE: %(program)s

> Worker (“slave”) process used in computing distributed LSI. Run this script on every node in your cluster. If you wish, you may even run it multiple times on a single machine, to make better use of multiple cores (just beware that memory footprint increases accordingly).

Example: python -m gensim.models.lsi_worker